@@ -16,7 +16,7 @@ from .sources import URL, Source
 from .pages import Page
 
 
-VERSION = "0.8.2"
+VERSION = "0.8.3"
 
 
 def scraper_params(func: typing.Callable) -> typing.Callable:
@@ -81,10 +81,10 @@ def scraper_params(func: typing.Callable) -> typing.Callable:
         )
         scraper.timeout = timeout
         scraper.user_agent = user_agent
-        # double ignore, weird issue on 3.7?
-        scraper.headers = {  # type: ignore
-            k.strip(): v.strip() for k, v in [h.split(":") for h in header]
-        }  # type: ignore
+        # only update headers, don't overwrite defaults
+        scraper.headers.update(
+            {k.strip(): v.strip() for k, v in [h.split(":") for h in header]}
+        )
         if fastmode:
             scraper.cache_storage = SQLiteCache("spatula-cache.db")
             scraper.cache_write_only = False
